package
Version:
v0.1.4
Opens a new window with list of versions in this module.
Published: Jun 13, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Input struct {
Kind string `json:"kind"`
PodSpec map[string]interface{} `json:"podSpec"`
Container map[string]interface{} `json:"container"`
}
type Result struct {
Allowed bool `json:"allowed"`
RuleID string `json:"rule_id,omitempty"`
Message string `json:"message,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.